@@ -6,7 +6,9 @@
 .onLoad <- function(libname, pkgname) {
 
   ## configure dependency requirements of python modules
-  reticulate::configure_environment(pkgname)
+  if (Sys.getenv("RETICULATE_AUTOCONFIGURE") != "FALSE") {
+    reticulate::configure_environment(pkgname)
+  }
 
   ## prepare required python modules for delayed package loading
   utils::assignInMyNamespace(".pyjoblib", reticulate::import("joblib", delay_load = TRUE))
